@@ -1,13 +1,15 @@
 from __future__ import annotations
 
 from enum import Enum, EnumMeta
-from typing import Any, Callable, cast
+from typing import TYPE_CHECKING, Any, Callable, cast
 
 from magicgui.types import ChoicesType, Undefined, _Undefined
-from magicgui.widgets import protocols
 
 from ._value_widget import T, ValueWidget
 
+if TYPE_CHECKING:
+    from magicgui.widgets import protocols
+
 
 class CategoricalWidget(ValueWidget[T]):
     """Widget with a value and choices.  Wraps CategoricalWidgetProtocol.
@@ -137,7 +139,9 @@ class CategoricalWidget(ValueWidget[T]):
             str_func = choices["key"]
         elif not isinstance(choices, EnumMeta) and callable(choices):
             _choices = choices(self)
-
+            # ensure that when setting choices with a callable,
+            # the default choices are also updated with that callable
+            self._default_choices = choices
         else:
             _choices = choices
 
