@@ -2,7 +2,7 @@ import datetime
 import inspect
 from enum import Enum
 from pathlib import Path
-from typing import Tuple
+from typing import Optional, Tuple
 from unittest.mock import MagicMock, patch
 
 import pytest
@@ -289,6 +289,21 @@ def test_bound_values():
     assert f() == 5
 
 
+def test_bound_unknown_type_annotation():
+    """Test that we can bind a "permanent" value override to a parameter."""
+
+    import numpy as np
+
+    def _provide_value(_):
+        return np.array(1)
+
+    @magicgui(arr={"bind": _provide_value})
+    def f(arr: np.ndarray) -> np.ndarray:
+        return arr
+
+    assert f() == np.array(1)
+
+
 def test_binding_None():
     """Test that we can bind a "permanent" value override to a parameter."""
 
@@ -440,7 +455,7 @@ def test_range_value_none():
     """Test that arg: int = None defaults to 0"""
 
     @magicgui
-    def f(x: int = None):  # type: ignore
+    def f(x: Optional[int] = None):  # type: ignore
         ...
 
     assert f.x.value == 0
@@ -706,6 +721,23 @@ def test_categorical_change_choices(Cls):
     assert wdg.choices == c
 
 
+@pytest.mark.parametrize("Cls", [widgets.ComboBox, widgets.RadioButtons])
+def test_categorical_change_choices_callable(Cls):
+    first_choices = ("a", "b")
+
+    def get_choices(wdg):
+        return ("c", "d")
+
+    wdg = Cls(choices=first_choices)
+    assert wdg.choices == first_choices
+    assert wdg._default_choices == first_choices
+
+    wdg.choices = get_choices
+
+    assert wdg.choices == ("c", "d")
+    assert wdg._default_choices == get_choices
+
+
 @pytest.mark.skipif(use_app().backend_name != "qt", reason="only on qt")
 def test_radiobutton_reset_choices():
     """Test that reset_choices doesn't change the number of buttons."""
@@ -737,7 +769,7 @@ def test_slider_readeout():
     sld = widgets.Slider()
     sld.show()
     backend_slider = sld.native.children()[1]
-    assert "QSpinBox" in type(backend_slider).__name__
+    assert "SpinBox" in type(backend_slider).__name__
     assert backend_slider.isVisible()
 
     sld = widgets.Slider(readout=False)
